<?php

/**
 * @file
 * Admin page callbacks for the drush_help module.
 */

require_once dirname(__FILE__) . '/drush_help.helpers.inc';

/**
 * Menu callback; prints a page listing general help for a module.
 *
 * @param string $name
 *   A module name to display a help page for.
 */
function help_page($name) {
  $output = '';
  if (module_hook($name, 'help')) {
    $info = system_get_info('module');
    drupal_set_title($info[$name]['name']);

    $temp = module_invoke($name, 'help', "admin/help#$name", drupal_help_arg());
    if (empty($temp)) {
      $output .= t("No help is available for module %module.", array('%module' => $info[$name]['name']));
    }
    else {
      $output .= $temp;
    }
    // Adding the drush help section.
    // Loading the drush command file.
    if (module_load_include('inc', $name, $name . '.drush')) {
      // Calling the module hook_drush_command to get the drush command
      // definitions.
      $drush_commands = _drush_help_call_user_func($name . '_drush_command');
      // Creating the drush command help section.
      $drush_help = _drush_help_drush_get_drush_command_help($drush_commands);
      $output .= render($drush_help);
    }

    // Only print list of administration pages if the module in question has
    // any such pages associated to it.
    $admin_tasks = system_get_module_admin_tasks($name, $info[$name]);
    if (!empty($admin_tasks)) {
      $links = array();
      foreach ($admin_tasks as $task) {
        $links[] = l($task['title'], $task['link_path'], $task['localized_options']);
      }
      $output .= theme('item_list', array(
        'items' => $links,
        'title' => t('@module administration pages', array('@module' => $info[$name]['name'])),
      ));
    }
  }
  return $output;
}
